/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Felamimail **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Felamimail'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:51+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Spanish (http://www.transifex.com/tine20/tine20/language/es/)\nLanguage: es\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=2; plural=(n != 1);\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "Can not combine \"allow external\" and \"allow only members\""
: ""

, "Delete"
: "Borrar"

, "Reply"
: "Contestar"

, "Reply To All"
: "Contestar a todos"

, "Forward"
: "Reenviar"

, "Print Message"
: "Imprimir Mensaje"

, "Print Preview"
: "Imprimir previsualización"

, "Add New Account"
: ""

, "Permissions"
: ""

, "Rules"
: ""

, "Vacation, Vacations"
: [
  "Vacaciones"
 ,"Vacaciones"

]
, "Account, Accounts"
: [
  "Cuenta"
 ,"Cuentas"

]
, "Account Name"
: "Nombre de la Cuenta"

, "Type"
: ""

, "Migration Approved"
: ""

, "Approve Migration"
: ""

, "Do you want to approve the migration of this account?"
: ""

, "User"
: ""

, "User Email"
: "Usuario de Email"

, "User Name (From)"
: "Usuario de Email (De)"

, "Organization"
: "Organización"

, "Signature position"
: "Posición de la Firma"

, "Above the quote"
: "Por encima de la Cuota"

, "Below the quote"
: "Por debajo de la Cuota"

, "IMAP"
: "IMAP"

, "Host"
: "Dominio"

, "Port (Default: 143 / SSL: 993)"
: "Puerto ( por Defecto: 143 / SSL: 993)"

, "Secure Connection"
: "Conexión Segura"

, "None"
: "Ninguno"

, "TLS"
: "TLS"

, "SSL"
: "SSL"

, "Username"
: "Usuario"

, "Password"
: "Contraseña"

, "Test IMAP Connection"
: ""

, "SMTP"
: "SMTP"

, "Port (Default: 25)"
: "Puerto (por Defecto: 25)"

, "Authentication"
: "Autentificación"

, "Login"
: "Ingreso"

, "Plain"
: "Plano"

, "Username (optional)"
: "Nombre de usuario (opcional)"

, "Password (optional)"
: "Contraseña (opcional)"

, "Test SMTP Connection"
: ""

, "Sieve"
: "Umbral"

, "Port (Default: 2000)"
: "Puerto (por Defecto: 2000)"

, "Notification Email"
: ""

, "Auto-move notifications"
: ""

, "Auto-move notifications folder"
: ""

, "Other Settings"
: "Otras Preferencias"

, "Sent Folder Name"
: "Nombre de Carpeta Enviados"

, "Trash Folder Name"
: "Nombre de carpeta Eliminados"

, "Drafts Folder Name"
: "Nombre de carpeta Borradores"

, "Templates Folder Name"
: "Nombre de carpeta Plantillas"

, "Display Format"
: "Mostrar Formato"

, "HTML"
: "HTML"

, "Plain Text"
: "Texto Plano"

, "Depending on content type (experimental)"
: "Depende del tipo de contenido (experimental)"

, "Compose Format"
: ""

, "Preserve Format"
: ""

, "No"
: ""

, "Yes"
: ""

, "Reply-To Email"
: ""

, "It is not possible to convert accounts because the config option EMAIL_USER_ID_IN_XPROPS is disabled."
: ""

, "Migration has not been approved."
: ""

, "It is not possible to convert the account to this type."
: ""

, "System accounts cannot be created manually."
: ""

, "Mailinglist accounts cannot be created manually."
: ""

, "Account type change not possible"
: ""

, "E-Mail account needs a password"
: ""

, "Use"
: ""

, "The grant use the shared email account"
: ""

, "Edit"
: ""

, "The grant edit the shared email account"
: ""

, "Send Mails"
: ""

, "The grant to send mails via the email account"
: ""

, "Warning"
: ""

, "Server connection failed. Do you still want to save this setting and exit?"
: ""

, "Connection succeed"
: ""

, "Connecting to {0} server..."
: ""

, "Connection failed"
: ""

, "{server} Connection Status"
: ""

, "Save Message as"
: ""

, "File (in Filemanager) ..."
: ""

, "Attachment (of Record)"
: ""

, "Download"
: ""

, "{messageCount, plural, one {Message was saved} other {# messages where saved}}"
: ""

, "Success"
: ""

, "Error"
: ""

, "Save Messages as Attachment"
: ""

, "No Messages found."
: ""

, "It is SPAM"
: ""

, "It is not SPAM"
: ""

, "Compose"
: "Redactar"

, "Toggle highlighting"
: "Cambiar seleccion"

, "Mark read/unread"
: "Marcar leído/no leído"

, "Move"
: ""

, "Copy"
: ""

, "Import Messages"
: ""

, "Add Account"
: "Añadir Cuenta"

, "No target folder selected"
: ""

, "You need to select a target folder for the messages."
: ""

, "Wrong File Type"
: ""

, "Files of type eml allowed only."
: ""

, "Importing Messages..."
: ""

, "Id"
: "Id"

, "Attachments"
: "Adjuntos"

, "Flags"
: "Banderas"

, "Subject"
: "Asunto"

, "From (Email)"
: "De (Email)"

, "From (Name)"
: "De (Nombre)"

, "Sender"
: "Remitente"

, "To"
: "Para"

, "Sent"
: "Enviado"

, "Received"
: "Recibido"

, "Folder, Folders"
: [
  "Carpeta"
 ,"Carpetas"

]
, "Size"
: "Tamaño"

, "Answered"
: "Contestado"

, "Forwarded"
: "Reenviado"

, "This message might be SPAM"
: ""

, "Tine20"
: ""

, "Encrypted Message"
: ""

, "Filed as:"
: ""

, "Select Message File Location"
: ""

, "Filing Messages"
: ""

, "Error Filing Message"
: ""

, "Could not file message."
: ""

, "Send Reading Confirmation"
: "Enviar Confirmación de Lectura"

, "Do you want to send a reading confirmation message?"
: "¿Desea enviar un mensaje de confirmación de lectura?"

, "Empty Folder"
: "Vaciar Carpeta"

, "Add Folder"
: "Añadir Carpeta"

, "New {0}"
: "Nueva {0}"

, "Please enter the name of the new {0}:"
: "Ingresar el nombre del nuevo {0}:"

, "No {0} added"
: "No {0} agregado"

, "You have to supply a {0} name!"
: "¡Ud. debe ingresar {0} nombre!"

, "Please wait"
: "Por favor espere"

, "Creating {0}..."
: "Creando {0}..."

, "Edit Account"
: "Editar Cuenta"

, "Edit Vacation Message"
: "Añadir Mensaje de Vacaciones"

, "Edit Filter Rules"
: "Editar Reglas de Filtrado"

, "Notifications"
: ""

, "Mark Folder as read"
: "Marcar carpeta como leída"

, "Update Folder List"
: "Actualizar lista de carpetas"

, "Message not available."
: "Mensaje no disponible"

, "Cancel"
: "Cancelar"

, "Ok"
: "Aceptar"

, "Folders of account {0}"
: "Carpetas de la Cuenta {0}"

, "Folders of all accounts"
: "Carpetas de todas las Cuentas"

, "Compose email"
: "Redactar email"

, "CC"
: ""

, "BCC"
: ""

, "Mass Mailing"
: ""

, "Open in Felamimail"
: ""

, "From"
: "De"

, "Add"
: "Agregar"

, "Add contact to addressbook"
: "Añadir contacto a la libreta de direcciones"

, "Date"
: "Fecha"

, "Show or hide header information"
: "Mostrar / Ocultar la información del Encabezado"

, "{locationCount, plural, one {This message is filed at the following location} other {This message is filed at the following locations}}: {locationsHtml}"
: ""

, "Open"
: ""

, "Save As"
: ""

, "{attachmentCount, plural, one {Attachment was saved} other {# Attachments where saved}}"
: ""

, "Save as Record Attachment"
: ""

, "This message is probably SPAM. Please help to train your anti-SPAM system with a decision: \"Yes, it is SPAM\" or \"No, it is not\""
: ""

, "Confirm SPAM Suspicion"
: ""

, "Yes, it is SPAM"
: ""

, "No, it is not"
: ""

, "(new message)"
: "(nuevo mensaje)"

, "Select recipients for \"{0}\""
: "Selecionar destinaratios para \"{0}\""

, "Signatures"
: ""

, "Name"
: ""

, "Is Default"
: ""

, "Add Signature"
: ""

, "Edit Signature"
: ""

, "Delete Signature"
: ""

, "Recipient filter"
: "Filtro de Destinatarios"

, "All recipients"
: "Todos los Destinatarios"

, "\"{0}\" recipients"
: "\"{0}\" Destinatarios"

, "Attachment"
: ""

, "Filemanager (Download link)"
: ""

, "Filemanager (Download link, password)"
: ""

, "Filemanager (Systemlink)"
: ""

, "Attachment Type"
: ""

, "Click icon to change"
: ""

, "name"
: ""

, "size"
: ""

, "type"
: ""

, "Vacation Message for {0}"
: "Mensaje de Fuera de Oficina para {0}"

, "Notification for {0}"
: ""

, "Move up"
: "Mover arriba"

, "Move down"
: "Mover abajo"

, "Enable"
: "Activado"

, "Disable"
: "Deshabilitado"

, "ID"
: "ID"

, "Conditions"
: "Condiciones"

, "Action"
: "Acción"

, "Keep a copy"
: ""

, "is greater than"
: "es mayor que"

, "is less than"
: "es menor que"

, "Header \"{0}\" contains \"{1}\""
: "Encabezado \"{0}\" contiene \"{1}\""

, "Header \"{0}\" matches \"{1}\""
: "Encabezado \"{0}\" coincide con \"{1}\""

, "Sieve Filter Rules"
: "Reglas de Filtrado "

, "Sieve Filter Rules for {0}"
: "Reglas de filtrado de correo para {0}"

, "From (Email and Name)"
: "De (Email y Nombre)"

, "To (Email)"
: "Para (email)"

, "To (Email CC)"
: "CC"

, "Header contains"
: "Contenido del Encabezado"

, "Header name"
: "Nombre de Encabezado"

, "Header value"
: "Valor del Encabezado"

, "Header regex"
: "Encabezado regex"

, "Edit Filter Rule"
: "Editar Regla de Filtrado"

, "Apply filter if"
: "Aplicar filtro si"

, "all conditions match"
: ""

, "any condition matches"
: ""

, "Do this action:"
: "Realizar la siguiente acción:"

, "Move mail to folder"
: "Mover correo a la carpeta"

, "Redirect mail to address"
: "Reenviar correo a"

, "Reject mail with this text"
: "Rechazar correo con el siguiente texto"

, "Discard mail"
: "Descartar correo"

, "Auto-Reply mail with this text"
: ""

, "Keep mail"
: "Guardar correo"

, "General"
: "General"

, "Advanced"
: "Avanzadas"

, "Only send all X days to the same sender"
: "Enviar únicamente todos los días X al mismo remitente"

, "Incoming mails will be answered with this text:"
: "Correos entrantes se responderán con este texto:"

, "Status"
: "Estado"

, "I am available (vacation message disabled)"
: "Estoy Disponible (Mensaje Fuera de Oficina deshabilitado)"

, "I am not available (vacation message enabled)"
: "No estoy Disponible (Mensaje de Fuera de Oficina activado)"

, "Start Date"
: "Fecha de inicio"

, "Set vacation start date ..."
: "Marcar fecha de comienzo"

, "End Date"
: "Fecha de fin"

, "Set vacation end date ..."
: "Marcar fecha de fin"

, "Representative #1"
: "Representante #1"

, "Choose first Representative ..."
: "Elegir primer Representate ..."

, "Representative #2"
: "Representante #2"

, "Choose second Representative ..."
: "Elegir segundo Representante ..."

, "Message Template"
: "Plantilla Mensaje"

, "Choose Template ..."
: "Seleccionar Plantilla..."

, "Mailvelope decryption Error [{0}]"
: ""

, "To decrypt this message please install {0} with API support enabled"
: ""

, "PGP encrypted Message"
: ""

, "GENDER_Message"
: ""

, "Message, Messages"
: [
  "Mensaje"
 ,"Mensajes"

]
, "Subject/From"
: "Asunto/De"

, "Cc"
: "Cc"

, "Bcc"
: "Bcc"

, "INBOX"
: "Bandeja de Entrada"

, "Drafts"
: "Borradores"

, "Templates"
: "Plantillas"

, "Junk"
: "Basura"

, "Trash"
: "Papelera"

, "GENDER_Folder"
: ""

, "record list, record lists"
: [
  "lista de registros"
 ,"listado de registros"

]
, "Rule, Rules"
: [
  "Regla"
 ,"Reglas"

]
, "Flag, Flags"
: [
  "Bandera"
 ,"Banderas"

]
, "Flag list, Flag lists"
: [
  "Lista de banderas"
 ,"Listados de Banderas"

]
, "Total Messages:"
: "Total de Mensajes:"

, "Unread Messages:"
: "Mensajes sin leer:"

, "Name on Server:"
: "Nombre en el Servidor:"

, "Last update:"
: "Última actualización:"

, "Fetching messages... ({0} done)"
: ""

, "{0} unread message, {0} unread messages"
: [
  "{0} mensaje Sin Leer"
 ,"{0} mensajes Sin Leer"

]
, "New Mail"
: "Nuevo Correo"

, "Email"
: "Email"

, "Active Vacation Message"
: "Activar Mensaje de Fuera de Oficina"

, "Email account \"{0}\" has an active vacation message."
: "Cuenta de correo \"{0}\" tiene activado Mensaje Fuera de Oficina"

, "Poll URL: {0}"
: ""

, "{0} as default mailer"
: ""

, "New mails"
: "Nuevos correos"

, "You got {0} new mail(s) in folder {1} ({2})."
: "Usted tiene {0} nuevo(s) mensaje(s) en {1} ({2})."

, "IMAP Credentials for {0}"
: "Credenciales IMAP para {0}"

, "Credentials"
: "Credenciales"

, "IMAP Error"
: "IMAP Error"

, "No connection to IMAP server."
: "Sin conexión con servidor IMAP."

, "IMAP Credentials Error"
: "IMAP Error de credenciales"

, "Your email credentials are wrong. Please contact your administrator"
: "Sus credenciales no son correctas. Favor de contactar al administrador."

, "One of your folders was deleted or renamed by another client. Please update the folder list of this account."
: "Hay una carpeta que fue eliminada o renombrada por otro usuaro. Favor de actualizar la lista de carpetas."

, "SMTP Error"
: "SMTP Error"

, "No connection to SMTP server."
: "Sin conexión con servidor SMTP"

, "Sieve Error"
: "Error de Filtro"

, "No connection to Sieve server."
: "Sin conexión al Servidor de Filtros"

, "Save Sieve Script Error"
: "Guardar error del script de filtro"

, "Could not save script on Sieve server."
: "No se pudo escribir el script en el Servidor de Filtrado"

, "Add as \"To\""
: "Agregar a \"Para\""

, "Add as \"Cc\""
: "Agregar a \"Cc\""

, "Add as \"Bcc\""
: "Agregar a \"Cco\""

, "Remove from recipients"
: "Eliminar de destinatarios"

, "Loading Mail Addresses"
: "Cargando Dirección de Correo"

, "Click here to set To/CC/BCC."
: "Click aquí para configurar Para/Cc/Cco"

, "To:"
: "Para:"

, "Cc:"
: "Cc:"

, "Bcc:"
: "Bcc:"

, "Remove"
: "Eliminar"

, "Send"
: "Enviar"

, "Search Recipients"
: "Buscar Destinatarios"

, "Save As Draft"
: "Guardar como Borrador"

, "Save As Template"
: "Guardar como Plantilla"

, "Reading Confirmation"
: "Confirmación de Lectura"

, "Activate this toggle button to receive a reading confirmation."
: "Activar este botón para recibir confirmación de lectura."

, "Encrypt Email"
: ""

, "Encrypt email using Mailvelope"
: ""

, "Activate this toggle button to send the mail as separate mail to each recipient."
: ""

, "Click to search for and add recipients from the Addressbook."
: "Click para buscar y agregar Destinatarios desde la Libreta de Direcciones."

, "Encrypted Content"
: ""

, "Discard this Draft?"
: ""

, "Do you want to discard the current draft?"
: ""

, "Fwd:"
: "Fwd:"

, "{0} Message"
: "{0} Mensajes"

, "Failed"
: "Error"

, "{0} account setting empty."
: "{0} configuración de cuenta vacía."

, "Files are still uploading."
: "Los archivos se están cargando."

, "{locationCount, plural, one {This message will be filed at the following location} other {This message will be filed at the following locations}}: {locationsHtml}"
: ""

, "On {0}, {1} wrote"
: "En {0}, {1} escritos"

, "Original message"
: "Mensaje Original"

, "Compose email:"
: "Redactar email:"

, "Convert to formated text"
: ""

, "Body"
: "Cuerpo"

, "NOTE: This is mail will be sent as a mass mail, i.e. each recipient will get his or her own copy."
: ""

, "Add email address here for reply-to"
: ""

, "Signature, Signatures"
: [
  ""
 ,""

]
, "Some attachments are of type \"systemlinks\" whereas some of the recipients (marked yellow), couldn't be validated to be accounts on this installation. Only recipients with an active account will be able to open those attachments."
: ""

, "Do you really want to send?"
: ""

, "Empty subject"
: "Asunto Vacío"

, "Do you really want to send a message with an empty subject?"
: "Desea envíar mensaje con Asunto vacío?"

, "No recipients set."
: "No hay Destinatarios"

, "Mass mailing is not allowed for CC or BCC recipients. Please remove them."
: ""

, "Cannot encrypt message. Public keys for the following recipients are missing: {0}"
: ""

, "All inboxes"
: "Todas las Bandejas de Entrada"

, "Default Email Account"
: "Dirección de correo por defecto"

, "The default email account to use when sending mails."
: "La Cuenta de Correo por defecto a utilizar para el envío de correos."

, "Mark Email Automatically As Read"
: ""

, "Is email marked as read automatically or by user action"
: ""

, "Email Update Interval"
: "Intervalo de actualización del Email"

, "How often should Felamimail check for new Emails (in minutes)."
: "Frecuencia para comprobar nuevos correos (en minutos)."

, "Use for mailto links"
: "Usar para enlaces mailto"

, "Use Felamimail in mailto links, otherwise use the default desktop client."
: ""

, "Use for NOTES"
: "Usar para Notas"

, "Save Note default Value."
: "Guardar Valor por defecto de la Nota."

, "Confirm Delete"
: "Confirmar Borrado"

, "Show confirmation dialog when deleting mails."
: "Mostrar diálogo de confirmación al Eliminar correos"

, ".eml file Attachment in forwarded mails"
: ""

, "Attach an .eml file to a forwarded mail. Otherwise all attachments separate"
: ""

, "Default Font"
: ""

, "Setting the default font in the E-Mail app"
: ""

, "Mail Type"
: ""

, "Possible mail types."
: ""

, "Additional Personal External Account"
: ""

, "Shared System Account"
: ""

, "Additional Personal System Account"
: ""

, "Default Personal System Account"
: ""

, "Mailinglist"
: ""

, "Mailinglist Reject Reason"
: ""

, "Your email has been rejected"
: ""

, "Vacation Templates Node ID"
: ""

, "Email Notification Templates Node ID"
: ""

, "Custom Vacation Message"
: "Personalizar mensaje de Fuera de Oficina"

, "User is allowed to set custom vacation message for system account"
: "Se permite al usuario configurar mensaje de Fuera de Oficina personalizado para la Cuenta del Sistema"

, "Cache email body"
: "Cache el cuerpo de correo"

, "Should the email body be cached (recommended for slow IMAP server connections)"
: "Mantener en caché el cuerpo del correo (recomendado para las conexiones del servidor IMAP lentos)"

, "Delete Archived Mail"
: ""

, "Prevent copying mails in the same account"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Felamimail Application."
: ""

, "Account Migration"
: ""

, "Shows context menu for system accounts to approve migration"
: ""

, "Move notifications"
: ""

, "Move notifications to a subfolder via sieve"
: ""

, "Auto-Save Drafts"
: ""

, "Save drafts automatically while editing an email"
: ""

, "Only password download link"
: ""

, "Allow only password download link"
: ""

, "Tine 2.0 Flag"
: ""

, "Add a Tine 2.0 flag to sent messages"
: ""

, "Show Reply-To"
: ""

, "Show Reply-To field in message compose dialog"
: ""

, "Auto-Create Folders"
: ""

, "Create template, trash, sent, draft and junks folders for system accounts"
: ""

, "Enable Spam Suspicion Strategy"
: ""

, "SEnable pam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy"
: ""

, "Spam Suspicion Strategy Config"
: ""

, "Spam User Processing Pipeline"
: ""

, "Confirm SPAM Suspicion Message"
: ""

, "Message for users when they press the info button in a SPAM suspicion toolbar."
: ""

, "Filter E-Mail URIs"
: ""

, "Should the email body uris be filtered. Only anchors with URIs are allowed if this is turned on"
: ""

, "System Account Folder Defaults"
: ""

, "Paths of the special folders (like Sent, Trash, ...)"
: ""

, "Allow self signed TLS cert for IMAP connection"
: ""

, "Sieve Redirect Only Internal"
: ""

, "Allow only sieve redirect rules to internal (primary/secondary) email addresses"
: ""

, "Sieve Notification Bounces Reporting Email"
: ""

, "URL icon path for own domain"
: ""

, "Used to mark messages from configured primary and secondary domains"
: ""

, "URL icon path for other domains"
: ""

, "Used to mark messages from all other domains"
: ""

, "Other domain regex for FLAG_ICON_OTHER_DOMAIN"
: ""

, "shared / adb_list accounts need to have a password set"
: ""

, "Is default"
: ""

, "Email Account, Email Accounts"
: [
  ""
 ,""

]
, "IMAP Host"
: ""

, "IMAP Port"
: ""

, "IMAP SSL"
: ""

, "Sent Folder"
: ""

, "Trash Folder"
: ""

, "Drafts Folder"
: ""

, "Templates Folder"
: ""

, "Reply-To"
: ""

, "E-Mail"
: ""

, "Signature Position"
: ""

, "SMTP Host"
: ""

, "SMTP Port"
: ""

, "SMTP SSL"
: ""

, "SMTP Authentication"
: ""

, "Sieve Host"
: ""

, "Sieve Port"
: ""

, "Sieve SSL"
: ""

, "Reading Confirmation:"
: "Confirmación de Lectura:"

, "Your message:"
: "Tu mensaje:"

, "Received on"
: "Recibido el"

, "Was read by:"
: "Fue leído por:"

, "on"
: "Activado"

, "Message File Location, Message File Locations"
: [
  ""
 ,""

]
, "Message File Locations"
: ""

, "Message ID Hash"
: ""

, "Message ID"
: ""

, "Model"
: ""

, "Record ID"
: ""

, "Record Title"
: ""

, "Node ID"
: ""

, "Message File Suggestion, Message File Suggestions"
: [
  ""
 ,""

]
, "Message File Suggestions"
: ""

, "Out of Office reply from %1$s"
: "Respuesta Fuera de Oficina desde %1$s"

, "It is not allowed to redirect emails to self! Please change the recipient."
: ""

, "Redirects to external email domains are not allowed."
: ""

, "You have new mail from "
: ""

, "shared / adb_list accounts need to have an email set"
: ""

, "userInternal accounts are only allowed with Tinebase_Config::EMAIL_USER_ID_IN_XPROPS"
: ""

, "userInternal accounts need to have an email set"
: ""

, "userInternal accounts need to have an user_id set"
: ""

, "Please choose a new email address for userInternal accounts"
: ""

, "system account for user does not exist"
: ""

, "Account type cannot be changed from {0} to {1}"
: ""

, "Config EMAIL_USER_ID_IN_XPROPS is not enabled! Please check if your email user backend supports it and run CLI method Tinebase.emailUserIdInXprops"
: ""

, "Migration of this account has not been approved!"
: ""

, "Could not find email user xprops!"
: ""

, "Internal user accounts need a valid user"
: ""

, "System account of user is missing"
: ""

, "Bad recipient address syntax"
: ""

, "Recipient address rejected"
: ""

, "Original message not found, email was moved or deleted"
: ""

, "Invalid address format"
: ""

, "Error: %s"
: "Error: %s"

, "Could not send message"
: "No se pudo enviar el mensaje"

, "My Mail Download Links"
: ""

, "Seen"
: "Visto"

, "Deleted"
: "Eliminado"

, "Draft"
: "Borrador"

, "Flagged"
: "Marcado"

, "It is not allowed to copy e-mails in the same account."
: ""

, "Folder with name {0} already exists!"
: ""

, "Failure on create folder"
: ""

, "All inboxes of my email accounts"
: "Todas las Bandejas de Entrada de mis Cuentas de Correo"

, "All unread mail"
: "Todos los mensajes No leídos"

, "All unread mail of my email accounts"
: "Tods los Correos Sin Leer de mis Cuentas de Correo"

, "All highlighted mail"
: "Todos los correos Destacados"

, "All highlighted mail of my email accounts"
: "Todo correo seleccionado en mi/s cuenta/s de correo"

, "All drafts"
: "Todos los Borradores"

, "All mails with the draft flag"
: "Todos los correos marcados como Borradores"

, "IMAP Hostname missing"
: ""

, "IMAP Credentials missing"
: ""

, "SMTP Hostname missing"
: ""

, "SMTP Credentials missing"
: ""

, "manage email accounts"
: "administrar cuentas de correo"

, "Edit and delete email accounts"
: "Editar y eliminar cuentas de correo"

, "Add email accounts"
: "Añadir cuentas de correo"

, "Create new email accounts"
: "Crear nueva cuenta de correo"

, "Vacation"
: "Vacaciones"

, "Account"
: "Cuenta"

, "Folder"
: "Carpeta"

, "Message"
: "Mensaje"

, "record list"
: "lista de registros"

, "Rule"
: "Regla"

, "Flag"
: "Bandera"

, "Flag list"
: "Lista de banderas"

, "{0} unread message"
: "{0} mensaje Sin Leer"

, "Signature"
: ""

, "Email Account"
: ""

, "Message File Location"
: ""

, "Message File Suggestion"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
